gamepads library

Classes

ControllerDatabase
Database of controller mappings, keyed by (vendorId, productId, platform).
GamepadConnectionEvent
Represents a gamepad controller being connected to or disconnected from the device.
GamepadController
Represents a single, currently connected joystick controller (or gamepad).
GamepadEvent
Represents a single "input" listened from a gamepad, i.e. a particular change on the state of the buttons and keys.
GamepadNormalizer
Transforms raw GamepadEvents into NormalizedGamepadEvents using platform-specific mappings.
Gamepads
NormalizedGamepadEvent
A gamepad event with platform-independent button/axis identifiers and normalized values.
NormalizedGamepadState
The current normalized state of a gamepad.
SdlMappingParser
Parses SDL GameController DB format mapping strings into ControllerMapping objects.
SdlParsedMapping
A parsed SDL mapping line with extracted metadata.

Enums

GamepadAxis
Standard gamepad axes modeled on the Xbox/standard gamepad layout.
GamepadButton
Standard gamepad buttons modeled on the Xbox/standard gamepad layout.
GamepadConnectionEventType
Whether a gamepad became available or unavailable.
GamepadPlatform
The platform this normalizer should use for mapping.
KeyType
What type of input is being pressed.
UnknownControllerBehavior
Behavior when encountering an unknown controller (no VID/PID match).