KeyType enum

What type of input is being pressed.

Inheritance
Available extensions

Values

analog → const KeyType

Analog inputs have a range of possible values depending on how far/hard they are pressed.

They represent analog sticks, back triggers, some kinds of d-pads, etc.

button → const KeyType

Buttons have only two states, pressed (1.0) or not (0.0).

They represent the face buttons, system buttons, and back bumpers, etc.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<KeyType>
A constant List of the values in this enum, in order of their declaration.