GamepadAxis enum
Standard gamepad axes modeled on the Xbox/standard gamepad layout.
Stick axes are normalized to -1.0 to 1.0 (Left/Down = -1, Right/Up = +1). Trigger axes are normalized to 0.0 to 1.0 (Released = 0, Fully pressed = 1).
Values
- leftStickX → const GamepadAxis
-
Left stick horizontal axis. -1.0 (left) to 1.0 (right).
- leftStickY → const GamepadAxis
-
Left stick vertical axis. -1.0 (down) to 1.0 (up).
- rightStickX → const GamepadAxis
-
Right stick horizontal axis. -1.0 (left) to 1.0 (right).
- rightStickY → const GamepadAxis
-
Right stick vertical axis. -1.0 (down) to 1.0 (up).
- leftTrigger → const GamepadAxis
-
Left trigger analog axis. 0.0 (released) to 1.0 (fully pressed).
- rightTrigger → const GamepadAxis
-
Right trigger analog axis. 0.0 (released) to 1.0 (fully pressed).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GamepadAxis> - A constant List of the values in this enum, in order of their declaration.