GamepadButton enum
Standard gamepad buttons modeled on the Xbox/standard gamepad layout.
This enum provides a platform-independent way to identify gamepad buttons. The layout follows the convention used by Xbox controllers, which iOS, Android, Web "standard" mapping, and SDL all converge on.
Values
- a → const GamepadButton
-
The bottom face button (A on Xbox, Cross on PlayStation).
- b → const GamepadButton
-
The right face button (B on Xbox, Circle on PlayStation).
- x → const GamepadButton
-
The left face button (X on Xbox, Square on PlayStation).
- y → const GamepadButton
-
The top face button (Y on Xbox, Triangle on PlayStation).
- leftBumper → const GamepadButton
-
The left shoulder bumper (LB on Xbox, L1 on PlayStation).
- rightBumper → const GamepadButton
-
The right shoulder bumper (RB on Xbox, R1 on PlayStation).
- leftTrigger → const GamepadButton
-
The left trigger as a digital button.
- rightTrigger → const GamepadButton
-
The right trigger as a digital button.
- back → const GamepadButton
-
The back/select/share button.
- start → const GamepadButton
-
The start/menu button.
- home → const GamepadButton
-
The home/guide button.
- leftStick → const GamepadButton
-
The left stick click (L3 on PlayStation).
- rightStick → const GamepadButton
-
The right stick click (R3 on PlayStation).
- dpadUp → const GamepadButton
-
D-pad up.
- dpadDown → const GamepadButton
-
D-pad down.
- dpadLeft → const GamepadButton
-
D-pad left.
- dpadRight → const GamepadButton
-
D-pad right.
- touchpad → const GamepadButton
-
The touchpad button (pressing the touchpad surface, available on PlayStation DualSense and DualShock controllers).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GamepadButton> - A constant List of the values in this enum, in order of their declaration.